@@ -103,4 +103,4 @@ PerfilClient = generate_wrapper_from_adapter(PerfilAdapter)
 OauthClient = generate_wrapper_from_adapter(OauthAdapter)
 LicencaClient = generate_wrapper_from_adapter(LicencaAdapter)
 JogoSelfClient = generate_wrapper_from_adapter(JogoSelfAdapter)
-RelatoriClient = generate_wrapper_from_adapter(RelatoriosAdapter)
+RelatorioClient = generate_wrapper_from_adapter(RelatoriosAdapter)
